import GameItem from "@/components/game-item"
import { Card } from "@/components/ui/card"
import { db } from "@/lib/db"
import { getFavoriteGames } from "@/lib/igdb"
import { getCurrentUser } from "@/lib/session"
import { IGame } from "@/types/igdb-types"
import { redirect } from "next/navigation"

export const ProfileUserContent = async ({ userid }: { userid: string }) => {
    const user = await getCurrentUser()

    const sessionUser = await db.user.findFirst({
        where: {
            id: user?.id
        },
        include: {
            following: true,
            followers: true
        }
    })

    const fullUser = await db.user.findFirst({
        where: {
            username: userid
        },
        include: {
            following: true,
            followers: true
        }
    })

    if (!fullUser) {
        redirect('/home')
    }

    let favoritegames = undefined
    let playingGames = undefined
    let finishedGames = undefined
    let planningGames = undefined

    if (fullUser?.favGameList?.length !== 0 && fullUser?.favGameList?.length != undefined) {
        favoritegames = await getFavoriteGames(fullUser?.favGameList!)
    }
    if (fullUser?.playingGameList?.length !== 0) {
        playingGames = await getFavoriteGames(fullUser?.playingGameList!)
    }
    if (fullUser?.finishedGameList?.length !== 0) {
        finishedGames = await getFavoriteGames(fullUser?.finishedGameList!)
    }
    if (fullUser?.planningGameList?.length !== 0) {
        planningGames = await getFavoriteGames(fullUser?.planningGameList!)
    }

    return (
        <>
            <Card className="overflow-hidden p-6 md:p-12" >
                <h1 className="text-2xl font-bold pb-3">Favorite Games</h1>
                <div className="grid grid-cols-1 ss:grid-cols-2 lg:grid-cols-3 xl:grid-cols-4 2xl:grid-cols-5 gap-4 lg:gap-8 items-center">
                    {favoritegames ? favoritegames.map((game: IGame) => (
                        <GameItem id={game.id} name={game.name} cover={game.cover} key={game.id} />
                    ))
                        :
                        <p>No favorites currently...</p>}
                </div>
            </Card>

            <Card className="overflow-hidden p-6 md:p-12" >
                <h1 className="text-2xl font-bold pb-3">Currently playing</h1>
                <div className="grid grid-cols-1 ss:grid-cols-2 lg:grid-cols-3 xl:grid-cols-4 2xl:grid-cols-5 gap-4 lg:gap-8 items-center">
                    {playingGames ? playingGames.map((game: IGame) => (
                        <GameItem id={game.id} name={game.name} cover={game.cover} key={game.id} />
                    ))
                        :
                        <p>Currently not playing any games...</p>}
                </div>
            </Card>

            <Card className="overflow-hidden p-6 md:p-12" >
                <h1 className="text-2xl font-bold pb-3">Planning to play</h1>
                <div className="grid grid-cols-1 ss:grid-cols-2 lg:grid-cols-3 xl:grid-cols-4 2xl:grid-cols-5 gap-4 lg:gap-8 items-center">
                    {planningGames ? planningGames.map((game: IGame) => (
                        <GameItem id={game.id} name={game.name} cover={game.cover} key={game.id} />
                    ))
                        :
                        <p>Currently not planning to play any games...</p>}
                </div>
            </Card>

            <Card className="overflow-hidden p-6 md:p-12" >
                <h1 className="text-2xl font-bold pb-3">Finished Games</h1>
                <div className="grid grid-cols-1 ss:grid-cols-2 lg:grid-cols-3 xl:grid-cols-4 2xl:grid-cols-5 gap-4 lg:gap-8 items-center">
                    {finishedGames ? finishedGames.map((game: IGame) => (
                        <GameItem id={game.id} name={game.name} cover={game.cover} key={game.id} />
                    ))
                        :
                        <p>No finished games...</p>}
                </div>
            </Card>
        </ >
    )
}